![](https://res.zhaoji.ac.cn/images/202301151046002.png)



<p align="center" color="#262626">
Providing a reactivity system similar to Vue.js for Python.
</p>


<p align="center">
<a href="https://pypi.org/project/pyreactivity/" target="_blank"><img src="https://img.shields.io/pypi/pyversions/pyreactivity" alt="pyversions"></a> <a href="https://pypi.org/project/pyreactivity/" target="_blank"><img src="https://img.shields.io/pypi/v/pyreactivity" alt="version"></a> <a href="https://github.com/frederick-wang/pyreactivity/blob/main/LICENSE" target="_blank"><img src="https://img.shields.io/pypi/l/pyreactivity" alt="license"></a> <a href="https://github.com/frederick-wang/pyreactivity" target="_blank"><img src="https://img.shields.io/github/last-commit/frederick-wang/pyreactivity" alt="last-commit"></a> <a href="https://github.com/frederick-wang/pyreactivity/commits/main" target="_blank"><img src="https://img.shields.io/github/commit-activity/m/frederick-wang/pyreactivity" alt="commit-activity"></a> <a href="https://github.com/frederick-wang/pyreactivity/actions/workflows/CI.yml" target="_blank"><img src="https://github.com/frederick-wang/pyreactivity/actions/workflows/CI.yml/badge.svg" alt="CI">
</p></a>

## Getting Started

Please follow the documentation at [pyreactivity.jianmu.org](https://pyreactivity.jianmu.org/)

## Supported features

- [x] `ref` function
- [x] `computed` function
- [x] `reactive` function
- [x] `effect` function
- [x] `watch` function
- [x] `watch_effect` ( `watchEffect` ) function
- [x] `is_ref` ( `isRef` ) function
- [x] `is_computed_ref` ( `isComputedRef` ) function
- [x] `unref` function
- [x] `deep_unref` ( `deepUnref` ) function
- [x] `is_reactive` ( `isReactive` ) function
- [x] `to_raw` ( `toRaw` ) function
- [x] `deep_to_raw` ( `deepToRaw` ) function
- [x] `mark_raw` ( `markRaw` ) function
- [x] serializable by `json.dumps()` and `json.dump()`

## Contributing

PyReactivity is an open-source project and welcomes any contributions. If you have any issues or suggestions, feel free to raise them in the [Github Issues](https://github.com/frederick-wang/pyreactivity/issues).

## Acknowledgments

PyReactivity is inspired by Vue.js and its implementation also references the source code of Vue.js. Thanks to the Vue.js team for their selfless dedication.

This documentation also heavily references the documentation of Vue.js, thanks to the document writers of Vue.js for their selfless dedication.
